@@ -1,5 +1,5 @@
 import os
-
+from .misc_utils import get_setting_from_context
 
 FF_ENV_DEV = 'fourfront-dev'  # Maybe not used
 FF_ENV_HOTSEAT = 'fourfront-hotseat'
@@ -45,7 +45,9 @@ FOURFRONT_STG_OR_PRD_NAMES = ['staging', 'stagging', 'data']
 
 # Done this way because it's safer going forward.
 CGAP_STG_OR_PRD_TOKENS = []
-CGAP_STG_OR_PRD_NAMES = [CGAP_ENV_WEBPROD, CGAP_ENV_PRODUCTION_GREEN, CGAP_ENV_PRODUCTION_BLUE, 'cgap']
+CGAP_STG_OR_PRD_NAMES = [CGAP_ENV_WEBPROD, CGAP_ENV_PRODUCTION_GREEN, CGAP_ENV_PRODUCTION_BLUE,
+                         CGAP_ENV_PRODUCTION_GREEN_NEW, CGAP_ENV_PRODUCTION_BLUE_NEW,
+                         'cgap']
 
 
 FF_PUBLIC_URL_STG = 'http://staging.4dnucleome.org'
@@ -87,6 +89,9 @@ BEANSTALK_PROD_MIRRORS = {
     FF_ENV_WEBPROD: FF_ENV_WEBPROD2,
     FF_ENV_WEBPROD2: FF_ENV_WEBPROD,
 
+    'staging': 'data',
+    'data': 'staging',
+
     CGAP_ENV_PRODUCTION_BLUE: CGAP_ENV_PRODUCTION_GREEN,
     CGAP_ENV_PRODUCTION_GREEN: CGAP_ENV_PRODUCTION_BLUE,
     CGAP_ENV_WEBPROD: None,
@@ -94,6 +99,8 @@ BEANSTALK_PROD_MIRRORS = {
     CGAP_ENV_PRODUCTION_BLUE_NEW: CGAP_ENV_PRODUCTION_GREEN_NEW,
     CGAP_ENV_PRODUCTION_GREEN_NEW: CGAP_ENV_PRODUCTION_BLUE_NEW,
 
+    'cgap': None,
+
 }
 
 BEANSTALK_TEST_ENVS = [
@@ -115,6 +122,36 @@ BEANSTALK_TEST_ENVS = [
 
 ]
 
+BEANSTALK_DEV_DATA_SETS = {
+
+    'fourfront-hotseat': 'prod',
+    'fourfront-mastertest': 'test',
+    'fourfront-webdev': 'prod',
+
+    'fourfront-cgapdev': 'test',
+    'fourfront-cgaptest': 'test',
+    'fourfront-cgapwolf': 'test',
+
+    'cgap-dev': 'test',
+    'cgap-test': 'test',
+    'cgap-wolf': 'test',
+
+}
+
+
+def data_set_for_env(envname, default=None):
+    """
+    This relates to which data set to load.
+    For production environments, really the null set is loaded because the data is already there and trusted.
+    This must always work for all production environments and there is deliberately no provision to override that.
+    In all other environments, the question is whether to load ADDITIONAL data, and that's a kind of custom choice,
+    so we consult a table for now, pending a better theory of organization.
+    """
+    if is_stg_or_prd_env(envname):
+        return 'prod'
+    else:
+        return BEANSTALK_DEV_DATA_SETS.get(envname, default)
+
 
 def blue_green_mirror_env(envname):
     """
@@ -162,7 +199,7 @@ def is_cgap_env(envname):
     Returns True of the given string looks like a CGAP elasticbeanstalk environment name.
     Otherwise returns False.
     """
-    return 'cgap' in envname
+    return 'cgap' in envname if envname else False
 
 
 def is_fourfront_env(envname):
@@ -170,7 +207,7 @@ def is_fourfront_env(envname):
     Returns True of the given string looks like a Fourfront elasticbeanstalk environment name.
     Otherwise returns False.
     """
-    return 'cgap' not in envname
+    return ('fourfront' in envname and 'cgap' not in envname) if envname else False
 
 
 def is_stg_or_prd_env(envname):
@@ -180,6 +217,8 @@ def is_stg_or_prd_env(envname):
     True whether or not they are actually the currently live instance. (This function doesn't change its
     state as blue or green is deployed, in other words.)
     """
+    if not envname:
+        return False
     stg_or_prd_tokens = CGAP_STG_OR_PRD_TOKENS if is_cgap_env(envname) else FOURFRONT_STG_OR_PRD_TOKENS
     stg_or_prd_names = CGAP_STG_OR_PRD_NAMES if is_cgap_env(envname) else FOURFRONT_STG_OR_PRD_NAMES
     if envname in stg_or_prd_names:
@@ -190,28 +229,23 @@ def is_stg_or_prd_env(envname):
 
 
 def is_test_env(envname):
-    return envname in BEANSTALK_TEST_ENVS
+    return envname in BEANSTALK_TEST_ENVS if envname else False
 
 
 def is_hotseat_env(envname):
-    return 'hot' in envname
+    return 'hot' in envname if envname else False
 
 
+# TODO: This variable and all the 'allow_environ=' arguments could go away in the next major version release.
+#       --Kent & Will 15-Apr-2020
 ALLOW_ENVIRON_BY_DEFAULT = True
 
 
 def get_env_from_context(settings, allow_environ=ALLOW_ENVIRON_BY_DEFAULT):
-    if allow_environ:
-        environ_env_name = os.environ.get('ENV_NAME')
-        if environ_env_name:
-            return environ_env_name
-    return settings.get('env.name')
+    return get_setting_from_context(settings, ini_var='env.name', env_var=None if allow_environ else False)
 
 
-def get_mirror_env_from_context(settings, allow_environ=ALLOW_ENVIRON_BY_DEFAULT, allow_guess=True, ):
-    # TODO: I added allow_environ featurism here but did not yet enable it.
-    #       Want to talk to Will about whether we should consider that a compatible or breaking hcange.
-    #       -kmp 27-Mar-2020
+def get_mirror_env_from_context(settings, allow_environ=ALLOW_ENVIRON_BY_DEFAULT, allow_guess=True):
     """
     Figures out who the mirror beanstalk Env is if applicable
     This is important in our production environment because in our
@@ -232,6 +266,39 @@ def get_mirror_env_from_context(settings, allow_environ=ALLOW_ENVIRON_BY_DEFAULT
         return None
 
 
+def get_standard_mirror_env(envname):
+    """
+    This function knows about the standard mirroring rules and infers a mirror env only from that.
+    (In tha sense, it is not guessing and probably needs to be renamed.)
+    If there is no mirror, it returns None.
+
+    An envname is usually a beanstalk environment name,
+    but this will also swap the special mirror names like 'staging' <=> 'data'.
+    For cgap, it may return None until/unless we start using a mirror for that, but the important thing
+    there is that again it will return a mirror if there is one, and otherwise None.
+
+    This is not the same as blue_green_mirror_env(envname), which is purely syntactic.
+
+    This is also not the same as get_mirror_env_from_context(...), which infers the mirror from contextual
+    information such as config files and environment variables.
+    """
+    return BEANSTALK_PROD_MIRRORS.get(envname, None)
+
+
 def guess_mirror_env(envname):
-    # TODO: Should this be BEANSTALK_PROD_MIRRORS.get(envname) or blue_green_mirror_env(envname)
-    return BEANSTALK_PROD_MIRRORS.get(envname)
+    """
+    Deprecated. This function returns what get_standard_mirror_env(envname) returns.
+    (The name guess_mirror_env is believed to be confusing.)
+    """
+    return get_standard_mirror_env(envname)
+
+
+def infer_repo_from_env(envname):
+    if not envname:
+        return None
+    if is_cgap_env(envname):
+        return 'cgap-portal'
+    elif is_fourfront_env(envname):
+        return 'fourfront'
+    else:
+        return None
